==> jc-1.4.0.tar.gz: gnu/classpath/VMStackWalker.c <==
// public final class gnu.classpath.VMStackWalker

// class file dependencies
// @dep_class a22ea65376bbc9d9 gnu_classpath_VMStackWalker
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 26b8d7b7a241db31 java_lang_ClassLoader
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String

// header file dependencies
// @dep_header gnu_classpath_VMStackWalker
// @dep_header java_lang_Class
// @dep_header java_lang_ClassLoader
// @dep_header java_lang_String

#include "jc_defs.h"

#include "gnu/classpath/VMStackWalker.h"
#include "java/lang/Class.h"
#include "java/lang/ClassLoader.h"
#include "java/lang/String.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static final native java.lang.Class getCallingClass()
//

static const unsigned char _jc_gnu_classpath_VMStackWalker$param_ptypes$getCallingClass$5954152cf8403ee7[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_classpath_VMStackWalker$method_info$getCallingClass$5954152cf8403ee7 = {
	.name=			"getCallingClass",
	.signature=		"()Ljava/lang/Class;",
	.class=			&_jc_gnu_classpath_VMStackWalker$type,
	.return_type=		&_jc_java_lang_Class$type,
	.param_ptypes=		&_jc_gnu_classpath_VMStackWalker$param_ptypes$getCallingClass$5954152cf8403ee7,
	.signature_hash=	_JC_JLONG(0x5954152cf8403ee7),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_gnu_classpath_VMStackWalker$method$getCallingClass$5954152cf8403ee7,
	.num_parameters=	0,
};

_jc_java_lang_Class$object *
_jc_gnu_classpath_VMStackWalker$method$getCallingClass$5954152cf8403ee7(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_gnu_classpath_VMStackWalker$method_info$getCallingClass$5954152cf8403ee7, &retval);
	return retval.l;
}

//
// public static final native java.lang.ClassLoader getCallingClassLoader()
//

static const unsigned char _jc_gnu_classpath_VMStackWalker$param_ptypes$getCallingClassLoader$620c5621c54f1125[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_classpath_VMStackWalker$method_info$getCallingClassLoader$620c5621c54f1125 = {
	.name=			"getCallingClassLoader",
	.signature=		"()Ljava/lang/ClassLoader;",
	.class=			&_jc_gnu_classpath_VMStackWalker$type,
	.return_type=		&_jc_java_lang_ClassLoader$type,
	.param_ptypes=		&_jc_gnu_classpath_VMStackWalker$param_ptypes$getCallingClassLoader$620c5621c54f1125,
	.signature_hash=	_JC_JLONG(0x620c5621c54f1125),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_gnu_classpath_VMStackWalker$method$getCallingClassLoader$620c5621c54f1125,
	.num_parameters=	0,
};

_jc_java_lang_ClassLoader$object *
_jc_gnu_classpath_VMStackWalker$method$getCallingClassLoader$620c5621c54f1125(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_gnu_classpath_VMStackWalker$method_info$getCallingClassLoader$620c5621c54f1125, &retval);
	return retval.l;
}

//
// public static final native java.lang.Class[] getClassContext()
//

static const unsigned char _jc_gnu_classpath_VMStackWalker$param_ptypes$getClassContext$90ec17340749d24e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_classpath_VMStackWalker$method_info$getClassContext$90ec17340749d24e = {
	.name=			"getClassContext",
	.signature=		"()[Ljava/lang/Class;",
	.class=			&_jc_gnu_classpath_VMStackWalker$type,
	.return_type=		&_jc_java_lang_Class$array$type,
	.param_ptypes=		&_jc_gnu_classpath_VMStackWalker$param_ptypes$getClassContext$90ec17340749d24e,
	.signature_hash=	_JC_JLONG(0x90ec17340749d24e),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_gnu_classpath_VMStackWalker$method$getClassContext$90ec17340749d24e,
	.num_parameters=	0,
};

_jc_object_array *
_jc_gnu_classpath_VMStackWalker$method$getClassContext$90ec17340749d24e(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_gnu_classpath_VMStackWalker$method_info$getClassContext$90ec17340749d24e, &retval);
	return retval.l;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_classpath_VMStackWalker$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_classpath_VMStackWalker$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_classpath_VMStackWalker$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_classpath_VMStackWalker$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_classpath_VMStackWalker$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_classpath_VMStackWalker$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_classpath_VMStackWalker$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_classpath_VMStackWalker, _init$52f4ad9f2989aeee);

void
_jc_gnu_classpath_VMStackWalker$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_classpath_VMStackWalker$object *this)
{
	struct _jc_gnu_classpath_VMStackWalker$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(52);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_classpath_VMStackWalker$methods[] = {
	&_jc_gnu_classpath_VMStackWalker$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_classpath_VMStackWalker$method_info$getCallingClass$5954152cf8403ee7,
	&_jc_gnu_classpath_VMStackWalker$method_info$getCallingClassLoader$620c5621c54f1125,
	&_jc_gnu_classpath_VMStackWalker$method_info$getClassContext$90ec17340749d24e
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_classpath_VMStackWalker$instanceof_hash_bucket_89[] = {
	&_jc_gnu_classpath_VMStackWalker$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_classpath_VMStackWalker$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_classpath_VMStackWalker$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[89]=	_jc_gnu_classpath_VMStackWalker$instanceof_hash_bucket_89,
	[113]=	_jc_gnu_classpath_VMStackWalker$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_classpath_VMStackWalker$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/ClassLoader",	_JC_JLONG(0x26b8d7b7a241db31) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_classpath_VMStackWalker$vtype _jc_gnu_classpath_VMStackWalker$type = {
    .type= {
	.name=			"gnu/classpath/VMStackWalker",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0xa22ea65376bbc9d9),
		.source_file=		"VMStackWalker.java",
		.instance_size=		sizeof(_jc_gnu_classpath_VMStackWalker$refs) + sizeof(_jc_gnu_classpath_VMStackWalker$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_classpath_VMStackWalker$methods) / sizeof(*_jc_gnu_classpath_VMStackWalker$methods),
		.methods=		_jc_gnu_classpath_VMStackWalker$methods,
		.instanceof_hash_table=	_jc_gnu_classpath_VMStackWalker$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_classpath_VMStackWalker$class_depends) / sizeof(*_jc_gnu_classpath_VMStackWalker$class_depends),
		.class_depends=		_jc_gnu_classpath_VMStackWalker$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_classpath_VMStackWalker= {
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/classpath/VMStackWalker.c <==
// public final class gnu.classpath.VMStackWalker

// class file dependencies
// @dep_class a22ea65376bbc9d9 gnu_classpath_VMStackWalker
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 58c6b9c5ce1fc756 java_lang_ClassLoader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String

// header file dependencies
// @dep_header gnu_classpath_VMStackWalker
// @dep_header java_lang_Class
// @dep_header java_lang_ClassLoader
// @dep_header java_lang_String

#include "jc_defs.h"

#include "gnu/classpath/VMStackWalker.h"
#include "java/lang/Class.h"
#include "java/lang/ClassLoader.h"
#include "java/lang/String.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static final native java.lang.Class getCallingClass()
//

static const unsigned char _jc_gnu_classpath_VMStackWalker$param_ptypes$getCallingClass$5954152cf8403ee7[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_classpath_VMStackWalker$method_info$getCallingClass$5954152cf8403ee7 = {
	.name=			"getCallingClass",
	.signature=		"()Ljava/lang/Class;",
	.class=			&_jc_gnu_classpath_VMStackWalker$type,
	.return_type=		&_jc_java_lang_Class$type,
	.param_ptypes=		&_jc_gnu_classpath_VMStackWalker$param_ptypes$getCallingClass$5954152cf8403ee7,
	.signature_hash=	_JC_JLONG(0x5954152cf8403ee7),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_gnu_classpath_VMStackWalker$method$getCallingClass$5954152cf8403ee7,
	.num_parameters=	0,
};

_jc_java_lang_Class$object * _JC_JCNI_ATTR
_jc_gnu_classpath_VMStackWalker$method$getCallingClass$5954152cf8403ee7(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_gnu_classpath_VMStackWalker$method_info$getCallingClass$5954152cf8403ee7, &retval);
	return retval.l;
}

//
// public static final native java.lang.ClassLoader getCallingClassLoader()
//

static const unsigned char _jc_gnu_classpath_VMStackWalker$param_ptypes$getCallingClassLoader$620c5621c54f1125[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_classpath_VMStackWalker$method_info$getCallingClassLoader$620c5621c54f1125 = {
	.name=			"getCallingClassLoader",
	.signature=		"()Ljava/lang/ClassLoader;",
	.class=			&_jc_gnu_classpath_VMStackWalker$type,
	.return_type=		&_jc_java_lang_ClassLoader$type,
	.param_ptypes=		&_jc_gnu_classpath_VMStackWalker$param_ptypes$getCallingClassLoader$620c5621c54f1125,
	.signature_hash=	_JC_JLONG(0x620c5621c54f1125),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_gnu_classpath_VMStackWalker$method$getCallingClassLoader$620c5621c54f1125,
	.num_parameters=	0,
};

_jc_java_lang_ClassLoader$object * _JC_JCNI_ATTR
_jc_gnu_classpath_VMStackWalker$method$getCallingClassLoader$620c5621c54f1125(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_gnu_classpath_VMStackWalker$method_info$getCallingClassLoader$620c5621c54f1125, &retval);
	return retval.l;
}

//
// public static final native java.lang.Class[] getClassContext()
//

static const unsigned char _jc_gnu_classpath_VMStackWalker$param_ptypes$getClassContext$90ec17340749d24e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_gnu_classpath_VMStackWalker$method_info$getClassContext$90ec17340749d24e = {
	.name=			"getClassContext",
	.signature=		"()[Ljava/lang/Class;",
	.class=			&_jc_gnu_classpath_VMStackWalker$type,
	.return_type=		&_jc_java_lang_Class$array$type,
	.param_ptypes=		&_jc_gnu_classpath_VMStackWalker$param_ptypes$getClassContext$90ec17340749d24e,
	.signature_hash=	_JC_JLONG(0x90ec17340749d24e),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_gnu_classpath_VMStackWalker$method$getClassContext$90ec17340749d24e,
	.num_parameters=	0,
};

_jc_object_array * _JC_JCNI_ATTR
_jc_gnu_classpath_VMStackWalker$method$getClassContext$90ec17340749d24e(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_gnu_classpath_VMStackWalker$method_info$getClassContext$90ec17340749d24e, &retval);
	return retval.l;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_gnu_classpath_VMStackWalker$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_gnu_classpath_VMStackWalker$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_gnu_classpath_VMStackWalker$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_gnu_classpath_VMStackWalker$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_classpath_VMStackWalker$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_classpath_VMStackWalker$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_classpath_VMStackWalker$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_classpath_VMStackWalker, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_gnu_classpath_VMStackWalker$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_gnu_classpath_VMStackWalker$object *this)
{
	struct _jc_gnu_classpath_VMStackWalker$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(52);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_classpath_VMStackWalker$methods[] = {
	&_jc_gnu_classpath_VMStackWalker$method_info$_init$52f4ad9f2989aeee,
	&_jc_gnu_classpath_VMStackWalker$method_info$getCallingClass$5954152cf8403ee7,
	&_jc_gnu_classpath_VMStackWalker$method_info$getCallingClassLoader$620c5621c54f1125,
	&_jc_gnu_classpath_VMStackWalker$method_info$getClassContext$90ec17340749d24e
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_classpath_VMStackWalker$instanceof_hash_bucket_89[] = {
	&_jc_gnu_classpath_VMStackWalker$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_classpath_VMStackWalker$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_classpath_VMStackWalker$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[89]=	_jc_gnu_classpath_VMStackWalker$instanceof_hash_bucket_89,
	[101]=	_jc_gnu_classpath_VMStackWalker$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_classpath_VMStackWalker$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/ClassLoader",	_JC_JLONG(0x58c6b9c5ce1fc756) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_classpath_VMStackWalker$vtype _jc_gnu_classpath_VMStackWalker$type = {
    .type= {
	.name=			"gnu/classpath/VMStackWalker",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0xa22ea65376bbc9d9),
		.source_file=		"VMStackWalker.java",
		.instance_size=		sizeof(_jc_gnu_classpath_VMStackWalker$refs) + sizeof(_jc_gnu_classpath_VMStackWalker$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_gnu_classpath_VMStackWalker$methods) / sizeof(*_jc_gnu_classpath_VMStackWalker$methods),
		.methods=		_jc_gnu_classpath_VMStackWalker$methods,
		.instanceof_hash_table=	_jc_gnu_classpath_VMStackWalker$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_classpath_VMStackWalker$class_depends) / sizeof(*_jc_gnu_classpath_VMStackWalker$class_depends),
		.class_depends=		_jc_gnu_classpath_VMStackWalker$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_classpath_VMStackWalker= {
	},
    }
};
